<?php

namespace Drupal\build_hooks_config_entity;

use Drupal\build_hooks\DeployLogger;
use Drupal\build_hooks\Trigger;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Class AzureManager.
 */
class BuildHooksConfigEntityManager {

  use StringTranslationTrait;
  use MessengerTrait;


  /**
   * Drupal\Core\Config\ConfigFactoryInterface definition.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * @var \Drupal\build_hooks\DeployLogger
   */
  protected $buildHooksDeployLogger;

  /**
   * @var \Drupal\build_hooks\Trigger
   */
  protected $buildHooksTrigger;


  /**
   * BuildHooksConfigEntityManager constructor.
   *
   * {@inheritDoc}
   */
  public function __construct(ConfigFactoryInterface $config_factory, DeployLogger $build_hooks_deploylogger, Trigger $build_hooks_trigger) {
    $this->configFactory = $config_factory;
    $this->buildHooksDeployLogger = $build_hooks_deploylogger;
    $this->buildHooksTrigger = $build_hooks_trigger;
  }


  /**
   * @param \Drupal\Core\Config\Entity\ConfigEntityInterface $entity
   *
   * @return bool
   */
  public function isEntityTypeLoggable(ConfigEntityInterface $entity) {
    $settings = $this->configFactory->get('build_hooks_config_entity.settings');
    if (!empty($settings['config_entities']) && $settings['config_entities'][$entity->getEntityTypeId()] == $entity->getEntityTypeId()) {
      return TRUE;
    }
  }

  /**
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *
   * @return bool
   */
  public function deployConfigEntity(EntityInterface $entity, $operation) {

    if (!$entity instanceof ConfigEntityInterface) {
      return FALSE;
    }
    if (!$this->isEntityTypeLoggable($entity)) {
      return FALSE;
    }
    switch ($operation) {
      case 'insert':
        $method = 'logEntityCreated';
        break;

      case 'update':
        $method = 'logEntityUpdated';
        break;

      case 'delete':
        $method = 'logEntityDeleted';
        break;

      default:
        return FALSE;

    }
    // Log the entity.
    call_user_func_array([$this->buildHooksDeployLogger, $method], [$entity]);
    $this->buildHooksTrigger->deployFrontendEntityUpdateEnvironments();
    $this->buildHooksTrigger->invalidateToolbarCacheTag();
  }

}
